"use strict";

exports.__esModule = true;
exports.useImageEvents = useImageEvents;

var _useEvent = _interopRequireDefault(require("../use-event"));

var _useLayoutEffect = _interopRequireDefault(require("../__modules__/useLayoutEffect"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * 
 */

/**
 * useImageEvents implementation
 */
function useImageEvents(targetRef, config) {
  var disabled = config.disabled,
      onError = config.onError,
      onLoad = config.onLoad;
  var errorHandle = (0, _useEvent.default)('error');
  var loadHandle = (0, _useEvent.default)('load');
  (0, _useLayoutEffect.default)(function () {
    var target = targetRef.current;

    if (target != null) {
      var image = target;
      loadHandle.setListener(target, !disabled && onLoad != null ? function load() {
        var naturalWidth = image.naturalWidth,
            naturalHeight = image.naturalHeight,
            width = image.width,
            height = image.height,
            currentSrc = image.currentSrc,
            src = image.src;
        var e = {
          naturalWidth: naturalWidth,
          naturalHeight: naturalHeight,
          width: width,
          height: height,
          currentSource: currentSrc != null ? currentSrc : src
        };
        onLoad(e);
      } : null);
      errorHandle.setListener(target, !disabled && onError != null ? onError : null);
    }
  }, [targetRef, disabled, errorHandle, loadHandle, onError, onLoad]);
}